@@ -5,11 +5,13 @@ from beanie.operators import And
 from AgentService.config import Config
 
 from AgentService.types.chat import ChatToolState, Chat
+from AgentService.types.message import Message
 from AgentService.enums.chat import ChatToolStateStatus
 
 from .models import (
     SendMessageRequest, SendMessageResponse,
-    GetStatesRequest, GetStatesResponse
+    GetStatesRequest, GetStatesResponse,
+    GetChatRequest, GetChatResponse
 )
 
 
@@ -33,6 +35,19 @@ async def send_message(request: SendMessageRequest) -> SendMessageResponse:
     )
 
 
+@chat_router.get("")
+async def get_chat(chat_id: str) -> GetChatResponse:
+    agent = Config().agent
+
+    chat = await agent.get_chat(chat_id=chat_id)
+    messages = await Message.find_many(Message.chat_id == chat.id).to_list()
+
+    return GetChatResponse(
+        data=messages,
+        status="ok"
+    )
+
+
 @chat_router.get("/states")
 async def get_states() -> GetStatesResponse:
     states = await ChatToolState.find_all().to_list()
