@@ -2,7 +2,7 @@
 from typing import Optional, Dict, List
 from pydantic import BaseModel, Field
 
-from AgentService.types import AgentResponse, ChatToolState, ToolAnswer
+from AgentService.types import AgentResponse, ChatToolState, ToolAnswer, Message
 from AgentService.enums.response import ResposneStatus
 
 
@@ -27,3 +27,13 @@ class GetStatesResponse(BaseModel):
     data: list[ChatToolState] = Field(default_factory=list)
     description: Optional[str] = None
     status: ResposneStatus
+
+
+class GetChatRequest(BaseModel):
+    chat_id: str
+
+
+class GetChatResponse(BaseModel):
+    data: list[Message] = Field(default_factory=list)
+    description: Optional[str] = None
+    status: ResposneStatus
