@@ -1,6 +1,6 @@
 
 from typing import Dict, List, Optional
-from pydantic import BaseModel, Op
+from pydantic import BaseModel
 
 from AgentService.types.storage import StorageItem
 from AgentService.enums.response import ResposneStatus
