@@ -3,6 +3,11 @@ from . import create
 from . import start
 from . import tool
 
+from . import create_nocode
+from . import start_nocode
+
+from . import image
+
 import click
 import os
 
@@ -13,7 +18,9 @@ from AgentService.config import Config
 
 __execute = click.CommandCollection(
     sources=[
-        create.group
+        create.group,
+        create_nocode.group,
+        image.group
     ],
     help='Use "agent <command> -h/--help" to see more info about a command',
 )
@@ -26,6 +33,13 @@ __execute_project = click.CommandCollection(
     help='Use "python3.11 manage.py <command> -h/--help" to see more info about a command',
 )
 
+__execute_project_nocode = click.CommandCollection(
+    sources=[
+        start_nocode.group
+    ],
+    help='Use "python3.11 manage.py <command> -h/--help" to see more info about a command',
+)
+
 
 def execute():
     __execute()
@@ -40,4 +54,8 @@ def execute_project():
     config = Config(current_path)
     setup_logger(config.log_path, config.log_level)
 
-    __execute_project()
+    if config.is_nocode:
+        __execute_project_nocode()
+
+    else:
+        __execute_project()
