@@ -1,6 +1,8 @@
 
 from . import Document
 
+from beanie.odm.documents import PydanticObjectId
+
 from .meta import TimestampMixin
 from .tool import Tool, ToolAnswer
 
@@ -8,11 +10,11 @@ from ..enums.message import MessageType
 
 
 class Message(TimestampMixin, Document):
-    chat_id: str
+    chat_id: PydanticObjectId
     type: MessageType
-    text: str = None
-    tools: list[Tool] = None
-    tool_answer: ToolAnswer = None
+    text: str | None = None
+    tools: list[Tool] | None = None
+    tool_answer: ToolAnswer | None = None
 
     @property
     def openai_model_dump(self) -> dict:
